@@ -267,8 +267,14 @@ fn build() -> io::Result<()> {
     // the binary using ffmpeg-sys cannot be redistributed
     switch(&mut configure, "BUILD_LICENSE_NONFREE", "nonfree");
 
+    let ffmpeg_major_version: u32 = env!("CARGO_PKG_VERSION_MAJOR").parse().unwrap();
+
     // configure building libraries based on features
-    for lib in LIBRARIES.iter().filter(|lib| lib.is_feature) {
+    for lib in LIBRARIES
+        .iter()
+        .filter(|lib| lib.is_feature)
+        .filter(|lib| !(lib.name == "avresample" && ffmpeg_major_version >= 5))
+    {
         switch(&mut configure, &lib.name.to_uppercase(), lib.name);
     }
 
@@ -284,11 +290,13 @@ fn build() -> io::Result<()> {
     enable!(configure, "BUILD_LIB_FREETYPE", "libfreetype");
     enable!(configure, "BUILD_LIB_FRIBIDI", "libfribidi");
     enable!(configure, "BUILD_LIB_OPENCV", "libopencv");
+    enable!(configure, "BUILD_LIB_VMAF", "libvmaf");
 
     // configure external encoders/decoders
     enable!(configure, "BUILD_LIB_AACPLUS", "libaacplus");
     enable!(configure, "BUILD_LIB_CELT", "libcelt");
     enable!(configure, "BUILD_LIB_DCADEC", "libdcadec");
+    enable!(configure, "BUILD_LIB_DAV1D", "libdav1d");
     enable!(configure, "BUILD_LIB_FAAC", "libfaac");
     enable!(configure, "BUILD_LIB_FDK_AAC", "libfdk-aac");
     enable!(configure, "BUILD_LIB_GSM", "libgsm");
@@ -411,7 +419,7 @@ fn check_features(
         let include = format!("#include <{}>", header);
         if !includes_code.contains(&include) {
             includes_code.push_str(&include);
-            includes_code.push_str(&"\n");
+            includes_code.push('\n');
         }
         includes_code.push_str(&format!(
             r#"
@@ -575,6 +583,7 @@ fn check_features(
         ("ffmpeg_4_2", 58, 54),
         ("ffmpeg_4_3", 58, 91),
         ("ffmpeg_4_4", 58, 100),
+        ("ffmpeg_5_0", 59, 18),
     ];
     for &(ffmpeg_version_flag, lavc_version_major, lavc_version_minor) in
         ffmpeg_lavc_versions.iter()
@@ -629,6 +638,7 @@ fn link_to_libraries(statik: bool) {
 
 fn main() {
     let statik = env::var("CARGO_FEATURE_STATIC").is_ok();
+    let ffmpeg_major_version: u32 = env!("CARGO_PKG_VERSION_MAJOR").parse().unwrap();
 
     let include_paths: Vec<PathBuf> = if env::var("CARGO_FEATURE_BUILD").is_ok() {
         println!(
@@ -649,7 +659,7 @@ fn main() {
             let reader = BufReader::new(file);
             let extra_libs = reader
                 .lines()
-                .find(|ref line| line.as_ref().unwrap().starts_with("EXTRALIBS"))
+                .find(|line| line.as_ref().unwrap().starts_with("EXTRALIBS"))
                 .map(|line| line.unwrap())
                 .unwrap();
 
@@ -700,14 +710,16 @@ fn main() {
             .probe("libavutil")
             .unwrap();
 
-        let libs = vec![
+        let mut libs = vec![
             ("libavformat", "AVFORMAT"),
             ("libavfilter", "AVFILTER"),
             ("libavdevice", "AVDEVICE"),
-            ("libavresample", "AVRESAMPLE"),
             ("libswscale", "SWSCALE"),
             ("libswresample", "SWRESAMPLE"),
         ];
+        if ffmpeg_major_version < 5 {
+            libs.push(("libavresample", "AVRESAMPLE"));
+        }
 
         for (lib_name, env_variable_name) in libs.iter() {
             if env::var(format!("CARGO_FEATURE_{}", env_variable_name)).is_ok() {
@@ -1062,92 +1074,93 @@ fn main() {
         .clang_args(clang_includes)
         .ctypes_prefix("libc")
         // https://github.com/rust-lang/rust-bindgen/issues/550
-        .blacklist_type("max_align_t")
-        .blacklist_function("_.*")
-        // Blacklist functions with u128 in signature.
+        .blocklist_type("max_align_t")
+        .blocklist_function("_.*")
+        // Blocklist functions with u128 in signature.
         // https://github.com/zmwangx/rust-ffmpeg-sys/issues/1
         // https://github.com/rust-lang/rust-bindgen/issues/1549
-        .blacklist_function("acoshl")
-        .blacklist_function("acosl")
-        .blacklist_function("asinhl")
-        .blacklist_function("asinl")
-        .blacklist_function("atan2l")
-        .blacklist_function("atanhl")
-        .blacklist_function("atanl")
-        .blacklist_function("cbrtl")
-        .blacklist_function("ceill")
-        .blacklist_function("copysignl")
-        .blacklist_function("coshl")
-        .blacklist_function("cosl")
-        .blacklist_function("dreml")
-        .blacklist_function("ecvt_r")
-        .blacklist_function("erfcl")
-        .blacklist_function("erfl")
-        .blacklist_function("exp2l")
-        .blacklist_function("expl")
-        .blacklist_function("expm1l")
-        .blacklist_function("fabsl")
-        .blacklist_function("fcvt_r")
-        .blacklist_function("fdiml")
-        .blacklist_function("finitel")
-        .blacklist_function("floorl")
-        .blacklist_function("fmal")
-        .blacklist_function("fmaxl")
-        .blacklist_function("fminl")
-        .blacklist_function("fmodl")
-        .blacklist_function("frexpl")
-        .blacklist_function("gammal")
-        .blacklist_function("hypotl")
-        .blacklist_function("ilogbl")
-        .blacklist_function("isinfl")
-        .blacklist_function("isnanl")
-        .blacklist_function("j0l")
-        .blacklist_function("j1l")
-        .blacklist_function("jnl")
-        .blacklist_function("ldexpl")
-        .blacklist_function("lgammal")
-        .blacklist_function("lgammal_r")
-        .blacklist_function("llrintl")
-        .blacklist_function("llroundl")
-        .blacklist_function("log10l")
-        .blacklist_function("log1pl")
-        .blacklist_function("log2l")
-        .blacklist_function("logbl")
-        .blacklist_function("logl")
-        .blacklist_function("lrintl")
-        .blacklist_function("lroundl")
-        .blacklist_function("modfl")
-        .blacklist_function("nanl")
-        .blacklist_function("nearbyintl")
-        .blacklist_function("nextafterl")
-        .blacklist_function("nexttoward")
-        .blacklist_function("nexttowardf")
-        .blacklist_function("nexttowardl")
-        .blacklist_function("powl")
-        .blacklist_function("qecvt")
-        .blacklist_function("qecvt_r")
-        .blacklist_function("qfcvt")
-        .blacklist_function("qfcvt_r")
-        .blacklist_function("qgcvt")
-        .blacklist_function("remainderl")
-        .blacklist_function("remquol")
-        .blacklist_function("rintl")
-        .blacklist_function("roundl")
-        .blacklist_function("scalbl")
-        .blacklist_function("scalblnl")
-        .blacklist_function("scalbnl")
-        .blacklist_function("significandl")
-        .blacklist_function("sinhl")
-        .blacklist_function("sinl")
-        .blacklist_function("sqrtl")
-        .blacklist_function("strtold")
-        .blacklist_function("tanhl")
-        .blacklist_function("tanl")
-        .blacklist_function("tgammal")
-        .blacklist_function("truncl")
-        .blacklist_function("y0l")
-        .blacklist_function("y1l")
-        .blacklist_function("ynl")
+        .blocklist_function("acoshl")
+        .blocklist_function("acosl")
+        .blocklist_function("asinhl")
+        .blocklist_function("asinl")
+        .blocklist_function("atan2l")
+        .blocklist_function("atanhl")
+        .blocklist_function("atanl")
+        .blocklist_function("cbrtl")
+        .blocklist_function("ceill")
+        .blocklist_function("copysignl")
+        .blocklist_function("coshl")
+        .blocklist_function("cosl")
+        .blocklist_function("dreml")
+        .blocklist_function("ecvt_r")
+        .blocklist_function("erfcl")
+        .blocklist_function("erfl")
+        .blocklist_function("exp2l")
+        .blocklist_function("expl")
+        .blocklist_function("expm1l")
+        .blocklist_function("fabsl")
+        .blocklist_function("fcvt_r")
+        .blocklist_function("fdiml")
+        .blocklist_function("finitel")
+        .blocklist_function("floorl")
+        .blocklist_function("fmal")
+        .blocklist_function("fmaxl")
+        .blocklist_function("fminl")
+        .blocklist_function("fmodl")
+        .blocklist_function("frexpl")
+        .blocklist_function("gammal")
+        .blocklist_function("hypotl")
+        .blocklist_function("ilogbl")
+        .blocklist_function("isinfl")
+        .blocklist_function("isnanl")
+        .blocklist_function("j0l")
+        .blocklist_function("j1l")
+        .blocklist_function("jnl")
+        .blocklist_function("ldexpl")
+        .blocklist_function("lgammal")
+        .blocklist_function("lgammal_r")
+        .blocklist_function("llrintl")
+        .blocklist_function("llroundl")
+        .blocklist_function("log10l")
+        .blocklist_function("log1pl")
+        .blocklist_function("log2l")
+        .blocklist_function("logbl")
+        .blocklist_function("logl")
+        .blocklist_function("lrintl")
+        .blocklist_function("lroundl")
+        .blocklist_function("modfl")
+        .blocklist_function("nanl")
+        .blocklist_function("nearbyintl")
+        .blocklist_function("nextafterl")
+        .blocklist_function("nexttoward")
+        .blocklist_function("nexttowardf")
+        .blocklist_function("nexttowardl")
+        .blocklist_function("powl")
+        .blocklist_function("qecvt")
+        .blocklist_function("qecvt_r")
+        .blocklist_function("qfcvt")
+        .blocklist_function("qfcvt_r")
+        .blocklist_function("qgcvt")
+        .blocklist_function("remainderl")
+        .blocklist_function("remquol")
+        .blocklist_function("rintl")
+        .blocklist_function("roundl")
+        .blocklist_function("scalbl")
+        .blocklist_function("scalblnl")
+        .blocklist_function("scalbnl")
+        .blocklist_function("significandl")
+        .blocklist_function("sinhl")
+        .blocklist_function("sinl")
+        .blocklist_function("sqrtl")
+        .blocklist_function("strtold")
+        .blocklist_function("tanhl")
+        .blocklist_function("tanl")
+        .blocklist_function("tgammal")
+        .blocklist_function("truncl")
+        .blocklist_function("y0l")
+        .blocklist_function("y1l")
+        .blocklist_function("ynl")
+        .opaque_type("__mingw_ldbl_type_t")
         .rustified_enum("*")
         .prepend_enum_name(false)
         .derive_eq(true)
@@ -1161,8 +1174,11 @@ fn main() {
             .header(search_include(&include_paths, "libavcodec/avcodec.h"))
             .header(search_include(&include_paths, "libavcodec/dv_profile.h"))
             .header(search_include(&include_paths, "libavcodec/avfft.h"))
-            .header(search_include(&include_paths, "libavcodec/vaapi.h"))
             .header(search_include(&include_paths, "libavcodec/vorbis_parser.h"));
+
+        if ffmpeg_major_version < 5 {
+            builder = builder.header(search_include(&include_paths, "libavcodec/vaapi.h"))
+        }
     }
 
     if env::var("CARGO_FEATURE_AVDEVICE").is_ok() {
